==> dasding.data-0.2-sources.jar: de/piratech/dasding/data/AbstractAction.java <==
//$URL: https://dasding.googlecode.com/svn/tags/dasding-0.2/data/src/main/java/de/piratech/dasding/data/AbstractAction.java $
//$Id: AbstractAction.java 26 2012-10-07 23:22:51Z amuthmann@gmail.com $
/*
 * Copyright 2012 Piratech.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.piratech.dasding.data;

import java.util.Date;

/**
 * An Abstract action used as base for actions and events
 *
 * @author deveth0
 */
public class AbstractAction extends AbstractDataObject {

  private User contact;
  private String name;
  private String description;
  private String finalWorks;
  private String furtherInformation;
  private Location location;
  private User responsible;
  private Date time;

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public User getContact() {
    return contact;
  }

  public void setContact(User contact) {
    this.contact = contact;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getFinalWorks() {
    return finalWorks;
  }

  public void setFinalWorks(String finalWorks) {
    this.finalWorks = finalWorks;
  }

  public String getFurtherInformation() {
    return furtherInformation;
  }

  public void setFurtherInformation(String furtherInformation) {
    this.furtherInformation = furtherInformation;
  }

  public Location getLocation() {
    return location;
  }

  public void setLocation(Location location) {
    this.location = location;
  }

  public User getResponsible() {
    return responsible;
  }

  public void setResponsible(User responsible) {
    this.responsible = responsible;
  }

  public Date getTime() {
    return time;
  }

  public void setTime(Date time) {
    this.time = time;
  }
}

==> dasding.data-0.3-sources.jar: de/piratech/dasding/data/AbstractAction.java <==
//$URL: https://dasding.googlecode.com/svn/tags/dasding-0.3/data/src/main/java/de/piratech/dasding/data/AbstractAction.java $
//$Id: AbstractAction.java 44 2012-10-11 13:48:26Z amuthmann@gmail.com $
/*
 * Copyright 2012 Piratech.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.piratech.dasding.data;

import java.util.Date;
import javax.xml.bind.annotation.XmlIDREF;
import org.apache.commons.lang3.StringUtils;

/**
 * An Abstract action used as base for actions and events
 *
 * @author deveth0
 */
public class AbstractAction extends AbstractDataObject {

  private User contact;
  private String name;
  private String description;
  private String finalWorks;
  private String furtherInformation;
  private Location location;
  private User responsible;
  private Date time;

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  //TODO: eventuell entfernen, dann sind Kontaktdaten immer sichtbar und nicht nur für angemeldete
  @XmlIDREF
  public User getContact() {
    return contact;
  }

  public void setContact(User contact) {
    this.contact = contact;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getFinalWorks() {
    return finalWorks;
  }

  public void setFinalWorks(String finalWorks) {
    this.finalWorks = finalWorks;
  }

  public String getFurtherInformation() {
    return furtherInformation;
  }

  public void setFurtherInformation(String furtherInformation) {
    this.furtherInformation = furtherInformation;
  }

  public Location getLocation() {
    return location;
  }

  public void setLocation(Location location) {
    this.location = location;
  }

  @XmlIDREF
  public User getResponsible() {
    return responsible;
  }

  public void setResponsible(User responsible) {
    this.responsible = responsible;
  }

  public Date getTime() {
    return time;
  }

  public void setTime(Date time) {
    this.time = time;
  }
  
  @Override
  public boolean isValid(){
    return StringUtils.isNotBlank(name) 
            && StringUtils.isNotBlank(description)
            && contact != null
            && time != null
            && location != null;
   
  }
}
